using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.Win32;
using PrintCENET;

namespace Sample_PrintCE
{
    public partial class Form1 : Form
    {
        private int mCurLang = 0; // default is english language

        public Form1()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            // 'Print' button
            Print(false);
        }

        private void button2_Click(object sender, EventArgs e)
        {
            // 'Print Silent' button
            Print(true);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            // 'Language' button
            ContextMenu menu = new ContextMenu();
            String[] menuStr = new String[6] {	"English","Russian","French","Portuguese","Italian","Dutch" };
            for (int i = 0; i < 6; i++)
            {
                menu.MenuItems.Add(new MenuItem());
                menu.MenuItems[i].Text = menuStr[i];
                menu.MenuItems[i].Click += new EventHandler(OnLangMenuClick);
            }
            menu.MenuItems[mCurLang].Checked = true;
            menu.Show(this, new Point(this.button3.Left + this.button3.Width / 2, this.button3.Top + this.button3.Height / 2));

        }

        private void button4_Click(object sender, EventArgs e)
        {
            // 'Exit' button
            Close();
        }

        protected void OnLangMenuClick(object sender, EventArgs e)
        {
            switch (((MenuItem)sender).Text)
            {
                case "English":
                    mCurLang = 0;
                    break;
                case "Russian":
                    mCurLang = 1;
                    break;
                case "French":
                    mCurLang = 2;
                    break;
                case "Portuguese":
                    mCurLang = 3;
                    break;
                case "Italian":
                    mCurLang = 4;
                    break;
                case "Dutch":
                    mCurLang = 5;
                    break;
            }
            
        }

        private void Print(bool silent)
        {
            PrintCE print1 = null;
            double y = 0.0;

            try
            {
                print1 = new PrintCE();
            }
            catch (Exception x)
            {
                MessageBox.Show(x.Message, "Error");
                return;
            }

            // library initialization (licence key is transfered as a parameter)
            print1.Init("My license key");

            // set language of the user interface
            print1.Language = mCurLang;

            // switch measuring units to inches
            print1.MeasureUnit = MeasureUnit.kInches;

            if (silent)
            {
                // don't show print setup dialog, just print to file 'silent_out.prn' for 'HP PCL' printer
                PrintInfo info = new PrintInfo();

                info.printer = 0;						// HP PCL
                info.port = 9;							// output to file
                info.portrait = true;					// portrait mode
                info.color_mode = 2;					// CMY colors
                info.draft_mode = false;				// no draft
                info.paper = 0;							// 'A4' paper for HP printer (see "PrintCE documentation")
                info.paper_width = 0;					// used only for 'custom paper'
                info.paper_height = 0;					// used only for 'custom paper'
                info.start_page = info.end_page = -1;	// to print all pages
                info.left_margin = info.right_margin = info.top_margin = info.bottom_margin = 0; // zero margins
                // set output file path
                String  reg_key = "HKEY_CURRENT_USER\\Software\\IneSoft\\PrintCE";
                Registry.SetValue(reg_key,"FilePath","\\silent_out.prn");
                // silent setup
                if (!print1.SilentPrintSetup(this.Handle, info))
                {
                    print1.UnInit();
                    print1.UnInit();
                    MessageBox.Show("SilentPrintSetup failed !", "Error");
                    return;
                }
                // disable progress dialog box
                print1.SilentMode = true;
            }
            else
            {
                // show print setup dialog
                if(!print1.SetupDlg(this.Handle))
                {
                    print1.UnInit();
                    return;
                }
            }

            // set margins
            print1.LeftMargin = 1.0;
            print1.RightMargin = 1.0;
            print1.TopMargin = 0.7;
            print1.BottomMargin = 0.7;

            // start printing document
            print1.StartDoc();

            // start printing page
            print1.StartPage();

            // print heading with font of 14 points in height, bold 
            print1.FontSize = 14.0;
            print1.FontBold = true;
            print1.DrawAlignedText("PrintCE for Pocket PC", print1.PageWidth / 2, y, TextHorAlign.hCenter, TextVertAlign.vTop);
            y += print1.GetTextHeight("PrintCE for Pocket PC");

            // print bitmap
            System.IO.Stream stream = System.Reflection.Assembly.GetCallingAssembly().GetManifestResourceStream("Sample_PrintCE.tiger.bmp");
            if (stream != null)
            {
                Bitmap bmp = new Bitmap(stream);
                if(print1.DrawBitmap(bmp, 0.0, y, 0.8, 0.0, true))
                    y += 0.9;
            }
            
            // set blue line colour
            print1.LineColor = Color.Blue;

            // set line width of 0.05 inches
            print1.LineWidth = 0.05;

            // print 3 blue lines of 2, 1.5 and 1 inches in length
            print1.DrawLine(0, y, 2.0, y);
            y += 0.3;
            print1.DrawLine(0, y, 1.5, y);
            y += 0.3;
            print1.DrawLine(0, y, 1.0, y);
            y += 0.3;

            // set yellow line colour
            print1.LineColor = Color.Yellow;

            // set green fill colour
            print1.FillColor = Color.Green;

            // print rectangle of 2 inches in length and 0.5 inch in width
            print1.DrawRect(0.0, y, 2.0, y + 0.5);

            // set line width of 0.01 inches
            print1.LineWidth = 0.01;

            // set black line colour
            print1.LineColor = Color.Black;

            // set red fill colour
            print1.FillColor = Color.Red;

            // print ellipse inside the rectangle
            print1.DrawEllipse(0.5, y + 0.05, 1.5, y + 0.45);

            y += 0.9;

            // print text with 9 points font 
            print1.FontBold = false;
            print1.FontSize = 9.0;
            print1.DrawText("http:\\\\www.inesoft.com", 0, y);

            // end printing document
            print1.EndDoc();

            // library deinitialization
            print1.UnInit();

            // show message for user
            if (silent)
                MessageBox.Show("Silent printing done !", "Sample PrintCE");
        }
    }
}